@@ -1,5 +1,5 @@
 /* This file is part of the Zebra server.
-   Copyright (C) 1994-2011 Index Data
+   Copyright (C) 2004-2013 Index Data
 
 Zebra is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -946,6 +946,8 @@ static void set_record_info(struct filter_info *tinfo,
             action = action_replace;
         else if (!strcmp(type_p, "update"))
             action = action_update;
+        else if (!strcmp(type_p, "adelete"))
+            action = action_a_delete;
         else
             dom_log(YLOG_WARN, tinfo, node, "bad @type value: %s", type_p);
         extctr->action = action;
@@ -1361,7 +1363,7 @@ static int extract_iso2709(struct filter_info *tinfo,
         dom_log(YLOG_WARN, tinfo, 0,
                 "MARC: Skipping bad byte %d (0x%02X)",
                 *buf & 0xff, *buf & 0xff);
-        for (i = 0; i<4; i++)
+        for (i = 0; i < 4; i++)
             buf[i] = buf[i+1];
 
         if (p->stream->readf(p->stream, buf+4, 1) != 1)
